from emod_api import schema_to_class as s2c
import json

schema_path = None
cases = -1
nodes = []

def SimpleSIA(Event_Name = "SIA", timestep=1, Target_Age_Min=0.75, Target_Age_Max=5.0, Coverage=1.0, nods = []):
    """
    Copied over from emodpy-generic. If this is expected to be used similarly in both modules, it probably
    belongs in emod-api.
    """

    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "StandardInterventionDistributionEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return ""
    try:
        coordinator.Max_Cases_Per_Node = cases
    except Exception as ex:
        # This can be fine because this is a new parameter only in some branches.
        # Obviously this question is more general and needs a better general solution
        # if at all possible. Max_Cases_Per_Node is an event coordinator optional param.
        print( str( ex ) ) 
    #coordinator.Target_Demographic = "ExplicitAgeRanges" # implicit
    coordinator.Target_Age_Max=Target_Age_Max
    coordinator.Target_Age_Min=Target_Age_Min

    event.Event_Coordinator_Config = coordinator
    # The intervention itself should be reused from another module
    # intervention = emodpy-generic.interventions.standard_generic_vaccine
    intervention = s2c.get_class_with_defaults( "SimpleVaccine", schema_path )
    intervention.Vaccine_Type = "AcquisitionBlocking"
    efficacy_profile = "WaningEffectConstant"
    waning = s2c.get_class_with_defaults( efficacy_profile, schema_path )
    waning.Initial_Effect = 0.999
    intervention.Waning_Config = waning
    coordinator.Intervention_Config = intervention
    event.Start_Day = float(timestep+1)

    if len(nods) > 0:
        nodelist = s2c.get_class_with_defaults( "NodeSetNodeList", schema_path )
        nodelist.Node_List = nods
        event.Nodeset_Config = nodelist
        nodelist.finalize()

    coordinator.finalize()
    intervention.finalize()
    waning.finalize()
    event.finalize()
    event["Event_Name"] = Event_Name

    return event

def basicSIAEvent(cov=1.0, genome=0, clade=0, start_day=1, nods=[]):
    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "StandardInterventionDistributionEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return ""
    try:
        coordinator.Max_Cases_Per_Node = cases
    except Exception as ex:
        # This can be fine because this is a new parameter only in some branches.
        # Obviously this question is more general and needs a better general solution
        # if at all possible. Max_Cases_Per_Node is an event coordinator optional param.
        print( str( ex ) ) 
    #coordinator.Target_Demographic = "ExplicitAgeRanges" # implicit
    coordinator.Target_Age_Max=5
    coordinator.Target_Age_Min=0
    coordinator.Demographic_Coverage = cov

    event.Event_Coordinator_Config = coordinator
    # The intervention itself should be reused from another module
    # intervention = emodpy-generic.interventions.standard_generic_vaccine
    intervention = s2c.get_class_with_defaults( "OutbreakIndividual", schema_path )
    intervention.Ignore_Immunity=0
    intervention.Incubation_Period_Override=1
    intervention.Genome=genome
    intervention.Clade=clade

    coordinator.Intervention_Config = intervention
    event.Start_Day = float(start_day)

    if len(nods) > 0:
        nodelist = s2c.get_class_with_defaults( "NodeSetNodeList", schema_path )
        nodelist.Node_List = nods
        event.Nodeset_Config = nodelist
        nodelist.finalize()

    coordinator.finalize()
    intervention.finalize()
    event.finalize()
    #event["Event_Name"] = Event_Name

    return event

